####
####
"""
Script to create the OnOff HPDPs for the chopnod observations

This version has been written to run on a set of obsids
The final products are the mosaic cubes -- the creation of the postcards is not part of this script

This script is based on the "Split On-Off" interactive pipeline scripts of HIPE - of which there is 
one for chop-nod range scans and one for chop-nod line scans. The only difference between these two is
in the flatfielding, and here we have put in a catch to determine whether the obsid is a line or 
range scan before doing the flatfielding. 
The main differences wrt to the Split On-Off pipelines are
- that the two on-source nod positions are averaged at the end, but the two off-source nod positions 
are not, producing one cube of on-source and two cubes of off-source. 
- a telescope background spectrum is subtracted (see the HPDP Release Note for details)   

Very few catches for potential errors (e.g. missing data due to instrument anomalies) are included 
in this script. It is worth checking the observations before running this to make sure that 
all the products taken from the observation by this script do actualy exist (e.g. that both 
cameras are present and correct). 

(Be aware are the few observations that have data in a very short spectral range at the 50 or 
190 micron edges, as these may fail at the flatfielding stage.) 

The main work done by this script is outsourced to 3 other HIPE scripts: toe run the pipeline, to subtract the telescope background 
and to create mosaic cubes. This way you can edit them to suit your needs. However, be careful of the naming used for the products 
that are read in and created by the scripts - if you change the names in only one of these subscripts, the next one will fail.

Note that for SEDs and mapping observations, this script can take a long time to run as the wavelength grid is very dense and 
the spatial grid large. 
 
"""

### Setup
obsids = [1342250905] # edit to add your own obsid(s)
datadir = "/Users/me/Data/"
scriptdir = "/Users/me/Scripts/"
cameras   = ["red","blue"] # if you want to process both cameras
calTree = getCalTree()

### Get the observation and some information for later
i=0
obsid = obsids[i]
obs=getObservation(obsid,useHsa=1)
aot = obs.meta["instMode"].value # PacsLineSpec or PacsRangeSpec


### Looping over camera
for camera in cameras:
  slicedCubes = obs.level2.getCamera(camera).cube.product
  execfile(scriptdir+"HPDP_OnOff_chopnod_pipeline.py") # meanRebinnedCubesOn|OffA|OffB
  execfile(scriptdir+"HPDP_OnOff_chopnod_telbackSubtract.py") # meanRebinnedCubesOn_resid and off
  execfile(scriptdir+"HPDP_ONOFF_chopnod_mosaicCubes.py") # create mosaic on and off cubes and write out
  # write out cubes as FITS files, slice by slice
  for slice in range(len(sCubesEquiOn.refs)):
      simpleFitsWriter(product=sCubesEquiOn.get(slice),file=datadir+filenOn)
  for slice in range(len(sCubesEquiOffA.refs)):
      simpleFitsWriter(product=sCubesEquiOffA.get(slice),file=datadir+filenOffA)
  for slice in range(len(sCubesEquiOffB.refs)):
      simpleFitsWriter(product=sCubesEquiOffB.get(slice),file=datadir+filenOffB)
#





