####
####
"""
Script to create the OnOff HPDPs for the unchopped line scan observations

This version has been written to run on a set of unchopped line scan obsids
The final products are the mosaic cubes -- the creation of the postcards is not part of this script.

Very few catches for potential errors (e.g. missing data due to instrument anomalies) are included 
in this script. It is worth checking the observations before running this to make sure that 
all the products taken from the observation by this script do actualy exist (e.g. that both 
cameras are present and correct).

The main difference in this script is that a telescope background is subtracted. See the HPDP Release Note for details. 

The main work done by this script is outsourced to 3 other HIPE scripts: toe run the pipeline, to subtract the telescope background 
and to create mosaic cubes. This way you can edit them to suit your needs. However, be careful of the naming used for the products 
that are read in and created by the scripts - if you change the names in only one of these subscripts, the next one will fail.

Note that for SEDs and mapping observations, this script can take a long time to run as the wavelength grid is very dense and 
the spatial grid large. 
"""

### Setup
obsids   = [1342214638] # edit to add your obsid(s)
cameras  = ["red","blue"] # if you want to process both cameras
datadir   = "/Users/me/Data/" # where you want the outputs to be stored
scriptdir =  "/Users/me/Scripts/"
calTree = getCalTree()

cubeTypeB = [] 
cubeTypeR = []

i = 0
obsid = obsids[i]
obs = getObservation(obsid,useHsa=1)
### Loop over the cameras
for camera in (cameras):
  slicedCubes = obs.level2.getCamera(camera).cube.product 
  execfile(scriptdir+"HPDP_OnOff_unchoppedLine_pipeline.py") # slicedOffFinalCubes and slicedOnFinalCubes are the output
  execfile(scriptdir+"HPDP_OnOff_unchoppedLine_telbackSubtract.py") # slicedOnFinalCubes_resid slicedOffFinalCubes_resid are the output
  execfile(scriptdir+"HPDP_OnOff_unchoppedLine_mosaicCubes.py") # create mosaic on and off cubes and write out
  # write cubes out as FITS files, one per slice. filenOn/Off comes out of mosaic task
  for slice in range(len(sCubesEquiOn.refs)):
      simpleFitsWriter(product=sCubesEquiOn.get(slice),file=datadir+filenOn)
  for slice in range(len(sCubesEquiOff.refs)):
      simpleFitsWriter(product=sCubesEquiOff.get(slice),file=datadir+filenOff)
#






