####
####
"""
Script to create the OnOff HPDPs for the unchopped range scan observations

This version has been written to run on a set of unchopped range on-off pairs
The final products are the mosaic cubes -- the creation of the postcards is not part of this script

Very few catches for potential errors (e.g. missing data due to instrument anomalies) are included 
in this script. It is worth checking the observations before running this to make sure that 
all the products taken from the observation by this script do actualy exist (e.g. that both 
cameras are present and correct).

The only data processing in this script is to subtract a telescope background (see the HPDP Release Note for details). 
Other than that, this script simply takes the rebinned cubes from Level 2 and creates mosaic cubes therefrom. 

Note that for SEDs and mapping observations, this script can take a long time to run as the wavelength grid is very dense and 
the spatial grid large. 

"""


### Setup
obsids_on  = [1342197900] # edit to add your obsid(s)
obsids_off = [1342197901]
cameras   = ["red","blue"] # if you want to process both cameras
calTree = getCalTree()
datadir   = "/Users/me/Data/" # where you want the outputs to be stored
scriptdir =  "/Users/me/Scripts/"

### Put into memory the functions that figure out what types of cubes to create and to subtract the 
### telescope spectrum from the HSA data. 
execfile(scriptdir+"HPDP_OnOff_unchoppedRange_decideMappingType.py") # for determineMappingAlgorithmMine
execfile(scriptdir+"HPDP_OnOff_unchoppedRange_telbackSubtract.py")    # for subtractTelBack_hpdps

### Getting the observations
i = 0
obsOn  = getObservation(obsids_on[i],useHsa=1)
obsOff = getObservation(obsids_off[i],useHsa=1)
filenon = "hpacs"+str(obsids_on[i]) # base of the filename of the outputs
filenoff = "hpacs"+str(obsids_off[i]) # base of the filename of the outputs

# What are the observing modes, and hence what cubes should I create? 
# The following are split by camera but will be the same for on and off
cubeTypeB, cubeTypeR, spaxelSizeB, spaxelSizeR = determineMappingAlgorithmMine(obsOn)

### Create the HPDPs in a loop over camera
for camera in (cameras):
  rcubesOn = obsOn.level2.getCamera(camera).rcube.product
  rcubesOn = subtractTelBack_hpdps(rcubesOn,obsOn)
  rcubesOff = obsOff.level2.getCamera(camera).rcube.product
  rcubesOff = subtractTelBack_hpdps(rcubesOff,obsOff)
  if camera == "red":
    if cubeTypeR == "interpolated":
      cubeNm = "_20hps3deqir"
      cubesRon = specInterpolate(rcubesOn,outputPixelsize = spaxelSizeR)
      cubesRoff = specInterpolate(rcubesOff,outputPixelsize = spaxelSizeR)
    elif cubeTypeR == "projected":
      cubeNm = "_20hps3deqpr"
      cubesRon = specProject(rcubesOn,outputPixelsize = spaxelSizeR)
      cubesRoff = specProject(rcubesOff,outputPixelsize = spaxelSizeR)
    # save cubes as FITS files, one per slice
    for slice in range(len(cubesRon.refs)):
      fln = datadir + filenon + cubeNm + "_ON_"+str(slice).zfill(2)+".fits"
      simpleFitsWriter(cubesRon.get(slice),fln)
      fln = datadir + filenoff + cubeNm + "_OFF_"+str(slice).zfill(2)+".fits"
      simpleFitsWriter(cubesRoff.get(slice),fln)
  if camera == "blue":
    if cubeTypeB == "interpolated":
      cubeNm = "_20hps3deqib"
      cubesBon = specInterpolate(rcubesOn,outputPixelsize = spaxelSizeB)
      cubesBoff = specInterpolate(rcubesOff,outputPixelsize = spaxelSizeB)
    elif cubeTypeB == "projected":
      cubeNm = "_20hps3deqpb"
      cubesBon = specProject(rcubesOn,outputPixelsize = spaxelSizeB)
      cubesBoff = specProject(rcubesOff,outputPixelsize = spaxelSizeB)
    # save cubes as FITS files, one per slice
    for slice in range(len(cubesBon.refs)):
      fln = datadir + filenon + cubeNm + "_ON_"+str(slice).zfill(2)+".fits"
      simpleFitsWriter(cubesBon.get(slice),fln)
      fln = datadir + filenoff + cubeNm + "_OFF_"+str(slice).zfill(2)+".fits"
      simpleFitsWriter(cubesBoff.get(slice),fln)
#





